@@ -108,9 +108,11 @@ default_service_yaml_schema = {
         "stages" : { "type" : "array" },
         "regions" : { "type" : "array" },
         "migrations" : { "type" : "boolean" },
+        "test" : { "type" : "boolean" },
+        "lint" : { "type" : "boolean" },
         "sfsp" : { "type" : "boolean" }
     },
-    "required": ["name", "type", "deploy", "stages", "regions", "migrations", "sfsp"]
+    "required": ["name", "type", "deploy", "stages", "regions", "migrations", "sfsp", "test", "lint"]
 }
 rollback_service_yaml_schema = {
     "type": "object",
@@ -358,6 +360,14 @@ def sls_sfsp(stage, region, chdir_path):
     run_bash(command)
     os.chdir(cwd)
 
+def nx_test(app):
+    command=f'nx run {app}:test'
+    run_bash(command)
+
+def nx_lint(app):
+    command=f'nx run {app}:lint'
+    run_bash(command)
+
 def populate_git_traits(app, branch, commit, version, author):
     app["branch"] = branch if branch else git_branch
     app["commit"] = commit if commit else git_commit
@@ -558,6 +568,28 @@ def run_sfsp_checks(app, stage, region):
 
     pass
 
+def run_test_checks(app, stage):
+    check_app_type(app, 'service')
+    check_app_stage_region(app, stage)
+
+    if app["test"] == False:
+        logging.info(f'Skipping {app["type"]} ({app["name"]}) test run...')
+        logging.info(f'Service ({app["name"]}) has no "test"')
+        sys.exit(0)
+
+    pass
+
+def run_lint_checks(app, stage):
+    check_app_type(app, 'service')
+    check_app_stage_region(app, stage)
+
+    if app["lint"] == False:
+        logging.info(f'Skipping {app["type"]} ({app["name"]}) lint run...')
+        logging.info(f'Service ({app["name"]}) has no "lint"')
+        sys.exit(0)
+
+    pass
+
 def run_rollback_service_checks(app, stage, region):
     check_app_type(app, 'service')
     check_app_stage_region(app, stage, region)
@@ -807,7 +839,7 @@ def rollback_service_cmd(stage, region, timestamp, app_dir, traits_input_file, t
 @cli.command("run-sfsp")
 @click.option('-r', '--region', required=True, type=str, help='Deployment region')
 @click.option('-s', '--stage', required=True, type=str, help='Deployment stage')
-@click.option('--app-dir', type=click.Path(exists=True, file_okay=False), default='.', help='App directory where to run sls rollback')
+@click.option('--app-dir', type=click.Path(exists=True, file_okay=False), default='.', help='App directory where to run sfsp')
 @click.option('--traits-input-file', type=click.Path(exists=True, file_okay=True, dir_okay=False, writable=True), default='traits.yml', help='Load traits file. Default (traits.yml)')
 @click.option('--traits-output-file', type=click.Path(exists=True, file_okay=True, dir_okay=False, writable=True), default='traits.yml', help='Updated traits file. Default (traits.yml)')
 def run_sfsp_cmd(stage, region, app_dir, traits_input_file, traits_output_file):
@@ -829,6 +861,34 @@ def run_sfsp_cmd(stage, region, app_dir, traits_input_file, traits_output_file):
     app["pipeline_metadata"]["sfsp"]["status"] = True
     write_traits_to_file(app, traits_output_file)
 
+@cli.command("run-test")
+@click.option('-s', '--stage', required=True, type=str, help='Deployment stage')
+@click.option('--traits-input-file', type=click.Path(exists=True, file_okay=True, dir_okay=False, writable=True), default='traits.yml', help='Load traits file. Default (traits.yml)')
+def run_test_cmd(stage, traits_input_file, traits_output_file):
+    app = load_traits_from_file(traits_input_file, default_service_yaml_schema)
+
+    run_test_checks(app, stage)
+
+    logging.info(f'{str(datetime.now(timezone.utc).replace(tzinfo=timezone.utc))} - Running test for service ({app["name"]})...')
+
+    nx_test(f'service-{app["name"]}')
+
+    logging.info(f'Tests ran successfully!')
+
+
+@cli.command("run-lint")
+@click.option('-s', '--stage', required=True, type=str, help='Deployment stage')
+@click.option('--traits-input-file', type=click.Path(exists=True, file_okay=True, dir_okay=False, writable=True), default='traits.yml', help='Load traits file. Default (traits.yml)')
+def run_lint_cmd(stage, traits_input_file, traits_output_file):
+    app = load_traits_from_file(traits_input_file, default_service_yaml_schema)
+
+    run_lint_checks(app, stage)
+
+    logging.info(f'{str(datetime.now(timezone.utc).replace(tzinfo=timezone.utc))} - Running lint for service ({app["name"]})...')
+
+    nx_lint(f'service-{app["name"]}')
+
+    logging.info(f'Lint ran successfully!')
 
 @cli.command("migrations-up-service")
 @click.option('-r', '--region', required=True, type=str, help='Deployment region')
